#include <kapp.h>
#include <qmessagebox.h>
#include <qkeycode.h>
#include "topwidget.h"


MyTopLevelWidget::MyTopLevelWidget(const char* name)
      :KTopLevelWidget(name),
       menu(this),statusbar(this),wview(this)
{
   QPopupMenu *popup;

   popup=new QPopupMenu;
   popup->insertItem(klocale->translate("&Quit"),this,SLOT(quit()),CTRL+Key_Q);
   menu.insertItem(klocale->translate("&File"),popup);
   
   popup=new QPopupMenu;
   popup->insertItem(klocale->translate("New &Game"),
                     &wview,SLOT(newGame()),CTRL+Key_G);
   popup->insertItem(klocale->translate("&New Round"),
                     &wview,SLOT(newRound()),CTRL+Key_N);
   menu.insertItem(klocale->translate("&Game"),popup);
   
   popup=new QPopupMenu;
   popup->insertItem(klocale->translate("&Keys..."),
                     &wview,SLOT(keySetup()),CTRL+Key_K);
   popup->insertItem(klocale->translate("&Game..."),
                     &wview,SLOT(gameSetup()),CTRL+Key_O);
   menu.insertItem(klocale->translate("&Options"),popup);

   popup=kapp->getHelpMenu(true,QString(i18n("KSpaceduel"))
                           +" "+VERSION
                           + i18n("\n\nby Andreas Zehender")
                           + " (azehende@ba-stuttgart.de)");
      
   menu.insertItem(klocale->translate("&Help"),popup);

   statusbar.setInsertOrder(KStatusBar::RightToLeft);
   statusbar.setBorderWidth(2);
   statusbar.insertItem(klocale->translate(" paused "),IDS_PAUSE);
   statusbar.insertItem("   ",IDS_MAIN);
   statusbar.setFrameStyle(QFrame::Panel|QFrame::Raised);

   QObject::connect(&wview,SIGNAL(setStatusText(const char*,int)),
                    SLOT(setStatusText(const char*,int)));

   setMenu(&menu);
   setView(&wview);
   setStatusBar(&statusbar);

   readConfig(kapp->getConfig());
}

void MyTopLevelWidget::start()
{
   wview.newGame();
   wview.newRound();
}

void MyTopLevelWidget::setStatusText(const char* str,int id)
{
   statusbar.changeItem(str,id);
}

void MyTopLevelWidget::readConfig(KConfig *cfg)
{
   QSize s(640,480);
   cfg->setGroup("Graphic");
   resize(cfg->readSizeEntry("WindowSize",&s));
   wview.readConfig(cfg);
}

void MyTopLevelWidget::writeConfig(KConfig *cfg)
{
   QSize s=size();
   cfg->setGroup("Graphic");
   cfg->writeEntry("WindowSize",s);
}

void MyTopLevelWidget::quit()
{
   writeConfig(kapp->getConfig());
   kapp->quit();
}
